extract_content_from_hl7_files: extract content from multiple hl7 files
Description
This function will extract content of the hl7. However, the content will not have the lable of the elements
Usage
extract_content_from_hl7_files(files, location)
Arguments
location
the path of the hl7 files, in case of
Value
a data.frame with headers and their corresponding elements with a sequence of column names, or NULL in case of no hl7 files